#ifndef GEN_CLUSTER_H
#define GEN_CLUSTER_H
#include <TObjArray.h>
#include <TVector3.h>

namespace GEN {
class Electron; 
class Track; 
class Hit;

class Cluster : public TObjArray {
friend Track;
public:
  Cluster(double   t     = 0.,
          TVector3 x     = TVector3(0.,0.,0.),
          Track   *trptr = nullptr,
          double   e     = 0.)
          : fT(t), fX(x), fTrPtr(trptr), fE(0.), 
	    fClPtr(nullptr), fHitPtr(nullptr) { if (trptr) SetOwner(); }  

  Cluster(Cluster *,  // src cluster
          Hit     *); // hit to which the cluster to be added if within acceptance

  inline int      GetClusterSize  () const { return GetEntries(); }
  inline double   GetTime         () const { return fT;           }
  inline TVector3 GetPosition     () const { return fX;           }
  inline Track   *GetTrackPtr     () const { return fTrPtr;       }
  inline double   GetEdeposit     () const { return fE;           }
  inline Cluster *GetSrcClusterPtr() const { return fClPtr;       }
  inline Hit     *GetHitPtr       () const { return fHitPtr;      }
  
  using TObjArray::Add;
  void Add(Electron *); 

private:
  inline void SetTrackPtr(Track   *trptr) { fTrPtr = trptr; }

private:
  double    fT;      // creation time [ns]
  TVector3  fX;      // cluster position
  Track    *fTrPtr;  // pointer to parent track
  double    fE;      // edep [keV]

  Cluster  *fClPtr;  // pointer to source cluster
  Hit      *fHitPtr; // pointer to hit it belongs to

  ClassDef(Cluster, 1) // ionization cluster class
};
}
#endif
