#include "Hit.h"
#include "Cluster.h"
#include "Electron.h"
#include "MPGD.h"
#include "Polya.h"

ClassImp(GEN::Hit)

namespace GEN {
const MPGD *Hit::GetMPGDPtr() const 
{ 
  fMPGDPtr->fgPolyaPtr->SetParameter(0,fMPGDPtr->fPolyaTheta);
  return fMPGDPtr;
} 

void Hit::Add(Cluster *cp)
{
  TObjArray::Add(cp);
  if (fDone) {
    fNsum = 0.;
    fCsum = 0.;
    fXcog = 0.;
    fTcog = 0.;
    fDone = false;
  }
}

void Hit::Update()
{
  if (fDone || !GetEntries()) return;
  GetMPGDPtr(); // This is necessary to properly set Polya's theta
  TIter nextcl(this);
  while (auto cp = static_cast<Cluster *>(nextcl())) {
    TIter next(cp);
    while (auto ep = static_cast<Electron *>(next())) {
      fNsum++;
      double gain = fMPGDPtr->GasAmplify();
#if 0
#else
      gain *= fMPGDPtr->Prf(ep->GetPosition().Y()); // Charge sharing betwenn neighboring rows.
#endif
      ep->fAmp = gain;
      fCsum += gain; 
      fXcog += gain * ep->GetPosition().X();
      fTcog += gain * ep->GetTime();
    }
  }
  if (fCsum > 0.) {
    fXcog /= fCsum;  // calculate the charge center of gravity
    fTcog /= fCsum;
  }
  fDone = true;
}
}
