#ifndef GEN_MPGD_H
#define GEN_MPGD_H
#include <TObject.h>

//--------------------------------
//  End plane Detector Information
//--------------------------------

class TF2;

#if 0
namespace TPC {
#else
namespace GEN {
#endif
class Polya;
}

namespace GEN {
class Electron;
class Track;
class Hit;

class MPGD : public TObject {
friend Hit;
public:
  MPGD(double dlenmax     = 60.,    // Maximum Drift Length [cm]
       double padpitch    = 0.116,  // Pad Pitch [cm]
       double padrowpitch = 0.536,  // Pad Row Pitch [cm]
       double vdrift      = 7.5e-3, // Drift Velocity [cm/ns]
       double cdt         = 95.e-4, // Transverse Diffusion Constant [cm/sqrt(cm)]
       double cdl         = 300.e-4,// Longitudinal Diffusion Constant [cm/sqrt(cm)]
       double avgasgain   = 2000.,  // Gas Gain Average
       double theta       = 0.6,    // Polya theta parameter for gas gain fluctuation
       double sigmaprf    = 0.027); // PRF width [cm]

  inline double GetMaxDriftLength   ()  const { return fDlenMax;               }
  inline double GetPadPitch         ()  const { return fPadPitch;              }
  inline double GetPadRowPitch      ()  const { return fPadRowPitch;           }
  inline double GetDriftVelocity    ()  const { return fDriftVelocity;         }
  inline double GetCdT              ()  const { return fCdT;                   }
  inline double GetCdL              ()  const { return fCdL;                   }
  inline double GetGasGainAverage   ()  const { return fGasGainAverage;        }
  inline double GetTheta            ()  const { return fPolyaTheta;            }
  inline double GetSigmaPRF         ()  const { return fSigmaPRF;              }

  void   Drift (Electron &e); // drift an electron
  void   Drift (Track    &t); // drift electrons belonging to a track

  double Prf    (const double *x, const double *p);
  double Prf    (int a, double x, double y);
  double Prf    (double y);

private:
  double GasAmplify();

private:
  double fDlenMax;          // Maximum drift length            [cm]
  double fPadPitch;         // Pad pitch                       [cm]
  double fPadRowPitch;      // Pad row pitch                   [cm]
  double fDriftVelocity;    // Drift veclocity                 [cm/ns]
  double fCdT;              // Transverse   diffusion constant [cm/sqrt(cm)]
  double fCdL;              // Longitudinal diffusion constant [cm/sqrt(cm)]
  double fGasGainAverage;   // Average gas gain
  double fPolyaTheta;       // Polya theta parameter
  double fSigmaPRF;         // PRF width [cm]

#if 0
  static TPC::Polya *fgPolyaPtr; //! Polya function for gas gain fluctuation
#else
  static GEN::Polya *fgPolyaPtr; //! Polya function for gas gain fluctuation
#endif
  static TF2        *fgPrfPtr;   //! 2D Pad Response Function

  ClassDef(MPGD, 1) // MPGD class
};  
}
#endif
