#include <iostream>
#include <sstream>
#include <fstream>

#include <TFile.h>
#include <TNtupleD.h>

void ProcessOneRun(const char *fname = "tup.electron.p0005.theta0.00.phi000.0.dlen025.0.root", 
                         int   flip  = 0,
                   const char *cond  = "")
{
  //--
  // Open output file
  //--
  ofstream ofile("sgx.dat",ios::app);
  TFile &file   = *new TFile(fname);
  TNtupleD &tup = *static_cast<TNtupleD *>(gROOT->FindObject("tup"));
  
  //--
  // Retrieve run conditions
  //--
  tup.Draw("padrowpitch>>hGeo","nev==1","goff");
  auto   hGeo   = static_cast<TH1D *>(gROOT->FindObject("hGeo"));
  double L      = hGeo->GetMean();

  tup.Draw("dlen>>hDlen","nev==1","goff");
  auto   hDlen  = static_cast<TH1D *>(gROOT->FindObject("hDlen"));
  double dlen   = hDlen->GetMean();

  tup.Draw("phi>>hPhi","nev==1","goff");
  auto   hPhi   = static_cast<TH1D *>(gROOT->FindObject("hPhi"));
  double phi    = hPhi->GetMean();
  if (flip%2) phi *= -1;

  tup.Draw("theta>>hTheta","nev==1","goff");
  auto   hTheta = static_cast<TH1D *>(gROOT->FindObject("hTheta"));
  double theta  = hTheta->GetMean();
  if (flip/2) theta *= -1;

  //--
  // Calculate Neff, Nheff, etc.
  //--
  auto hNsum  = new TH1D("hNsum","",1000,0.,1000);
  auto hNinv  = new TH1D("hNinv","",1000,0.,1.);
  auto hQ2sum = new TH1D("hQ2sum","",1000,0.,1.e10);
  auto hQsum  = new TH1D("hQsum","",1000,0.,1.e5);
  auto hK2sum = new TH1D("hK2sum","",1000,0.,10.);
  auto hFqc2  = new TH1D("hFqc2","",1000,0.,1.);
  auto hXcog  = new TH1D("hXcog","",500,-0.2,0.2);

  double nsum, q2sum, qsum, k2sum, qc2sum, xcog;
  tup.SetBranchAddress("nsum",&nsum);
  tup.SetBranchAddress("q2sum",&q2sum);
  tup.SetBranchAddress("qsum",&qsum);
  tup.SetBranchAddress("k2sum",&k2sum);
  tup.SetBranchAddress("qc2sum",&qc2sum);
  tup.SetBranchAddress("xcog",&xcog);

  int nlist = tup.GetEntries();
  //cerr << "nlist = " << nlist << endl;

  // ---------------
  // Loop over hits
  // ---------------
  for (int i=0; i<nlist; i++) {
    tup.GetEntry(i);
    hNsum->Fill(nsum);
    hNinv->Fill(1./nsum);
    hQ2sum->Fill(q2sum);
    hQsum->Fill(qsum);
    hK2sum->Fill(k2sum/nsum/nsum);
    hFqc2->Fill(qc2sum/qsum/qsum);
    hXcog->Fill(xcog);
  }

  double Nav    = hNsum->GetMean();
  double Neff   = 1./hNinv->GetMean();
  double q2tot  = hQ2sum->GetMean()*hQ2sum->Integral();
  double qtot   = hQsum->GetMean()*hQsum->Integral();
  double ntot   = Nav*hNsum->Integral();
  double Neffg  = Neff/(ntot*q2tot/(qtot*qtot));
  double Nheff  = 1./hK2sum->GetMean();
  double Nheffg = 1./hFqc2->GetMean();
  double sgx    = hXcog->GetRMS();
  double dsgx   = hXcog->GetRMSError();
  if (sgx > 0.) {
    //hXcog->Fit("gaus","Q","goff");
    hXcog->Fit("gaus","","goff");
    sgx    = hXcog->GetFunction("gaus")->GetParameter(2);
    dsgx   = hXcog->GetFunction("gaus")->GetParError (2);
  }

  //--
  // Write results
  //--
  cerr  << dlen  << " " << phi    << " " << theta << " " 
        << sgx   << " " << dsgx   << " " 
        << Nav   << " " << Neff   << " " << Neffg << " " 
	<< Nheff << " " << Nheffg << " " << L     << endl;

  ofile << dlen  << " " << phi    << " " << theta << " " 
        << sgx   << " " << dsgx   << " " 
        << Nav   << " " << Neff   << " " << Neffg << " " 
	<< Nheff << " " << Nheffg << " " << L     << endl;
  //--
  // That's it folks
  //--
}
