#!/bin/sh
# ============
#  manyrun.sh
# ============
#
# (Function)
#   Generate multiple track data sets
# (Usage)
#   manyrun <maxevt>
# (Upadate Record)
#   2021/03/05   K.Fujii         Original version.
#
#--
#  Check arguments.
#--
if [ $# -ge 2 ]; then
      echo "Usage:"
      echo "  ./manyrun <maxevt>"
      echo " where <maxevt> is the maximum number of events to generate"
      echo " per run with its default value being 10000."
      exit 0
#--
# Set maximum number of events to reconstruct per run
#--
elif [ $# -eq 1 ]; then
      echo "maxevt is set to $1"
      maxevt=$1
else
      maxevt=10000
fi
echo "Going to generate $maxevt events per run"
#--
# Other job parameters
#--
pid="electron"
p=5
theta=0
#--
# Loop over angles.
#--
#for dlen in 25; do
for dlen in 0 10 25 50 100 200; do
  for phi in 0 10 20 30; do
	echo ".............................."
	echo "Start generating dlen = $dlen phi = $phi ..."
	./gentrack $maxevt $dlen $phi $theta $p $pid >& run.$pid.p$p.theta$theta.phi$phi.dlen$dlen.log &
  done
done
wait
#--
# That's it, folks!
#--
exit 0
