#!/bin/sh
# ===========
#  phidep.sh
# ===========
#
# (Function)
#   Create phi vs sgx files from n-tuples created by "neff.sh" and stored in $datadir with "cuts"
#   on n-tuple variables.
#   By default datadir is set to pwd and cuts are empty.
# (Usage)
#   sh phidep.sh <datadir> <cuts>
# (Upadate Record)
#   2021/03/10   K.Fujii         Original version.
#
#--
#  Check arguments.
#--
if [ $# -ge 3 ]; then
      echo "Usage:"
      echo "  sh phidep.sh <datadir> <cuts>"
      echo " where <datadir> is the directory containing tup files"
      echo " and <cuts> are selection cuts on n-tuple variables."
      exit 0
#--
# Set the directory containing input tup files.
#   default is the current working directory.
#--
elif [ $# -ge 1 ]; then
      datadir=$1
      if [ $# -eq 2 ]; then
	      cuts=$2
      fi
else
      datadir=.
      cuts=""
fi
echo "datadir is set to $datadir"
echo "cuts used are $cuts"
#--
# Loop over drift lengths.
#--
#evalcmd=echo
evalcmd=eval
dlenlist=`ls $datadir/tup.* | sort -k 6 -t '.' | sed -e 's;.*dlen\([0-9]\{1,4\}\.[0-9]\{1,3\}\)\.root;\1;' | sort | uniq`
for i in $dlenlist; do
  rm -f sgx.dat
  listinv=`ls $datadir/tup.*dlen$i*.root | sort -r`
  for j in $listinv; do
    if [ `echo $j | grep -c "phi000.0"` = 0 ]; then
      $evalcmd "root -l -q -b ProcessOneRun.C\(\\\"$j\\\",1,\\\"$cuts\\\"\)"
    fi
  done
  list=`ls $datadir/tup.*dlen$i*.root`
  for j in $list; do
    $evalcmd "root -l -q -b ProcessOneRun.C\(\\\"$j\\\",0,\\\"$cuts\\\"\)"
  done
  mv "sgx.dat" "sgx.dlen$i.dat"
done
#--
# That's it, folks!
#--
exit 0
